# -*- coding: UTF-8 -*-

from unittest import TestCase
from pymecab.pymecab import PyMecab


def fs(x):
    return x if x is not None else '*' 


def token_to_str(token):
    features = [
        fs(token.pos1),
        fs(token.pos2),
        fs(token.pos3),
        fs(token.pos4),
        fs(token.conjugation_form),
        fs(token.conjugation_type),
        fs(token.base_form),
        fs(token.reading),
        fs(token.pronunciation)
    ]
    return '%s\t%s' % (token.surface, ','.join(features)) 


def test_mecab():
    text = '太郎は昨日、本を買った'

    expect = [
    '太郎\t名詞,固有名詞,人名,名,*,*,太郎,タロウ,タロー',
    'は\t助詞,係助詞,*,*,*,*,は,ハ,ワ',
    '昨日\t名詞,副詞可能,*,*,*,*,昨日,キノウ,キノー',
    '、\t記号,読点,*,*,*,*,、,、,、',
    '本\t名詞,一般,*,*,*,*,本,ホン,ホン',
    'を\t助詞,格助詞,一般,*,*,*,を,ヲ,ヲ',
    '買っ\t動詞,自立,*,*,五段・ワ行促音便,連用タ接続,買う,カッ,カッ',
    'た\t助動詞,*,*,*,特殊・タ,基本形,た,タ,タ',
    '\tEOS,*,*,*,*,*,*,*,*'
    ]

    tokenizer = PyMecab()
    actual = [token_to_str(token) for token in tokenizer.tokenize(text)]
    assert len(actual) == len(expect)

    for i in range(len(expect)):
        assert actual[i] == expect[i]



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name='pymecab',
    version='1.0.2',
    description='mecab wrapper by using natto-py',
    author='JX PRESS Corp.',
    author_email='info@jxpress.net',
    url='https://github.com/jxpress/pymecab',
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3 :: Only',
    ],
    packages=find_packages(), 
    include_package_data=True,
    keywords=['natural language processing', 'morphological analyzer', 'mecab'],
    license='MIT License',
    install_requires=[
        'natto-py'
    ],
    extras_require={
        'test': ['pytest']
    },
    entry_points={
        'console_scripts': [
            'pymecab.console=pymecab.pymecab:main'
        ]
    }


)



from collections import namedtuple

from natto import MeCab


Token = namedtuple('Token', ('surface', 'pos1', 'pos2', 'pos3', 'pos4', 'conjugation_form', 'conjugation_type', 'base_form', 'reading', 'pronunciation'))

Token.__new__.__defaults__ = (None, None, None, None, None, None, None, None, None, None)


class PyMecab:

    BOS = Token('', 'BOS', None, None, None, None, None, None, None, None)
    EOS = Token('', 'EOS', None, None, None, None, None, None, None, None)

    def __init__(self, options=None, **kwargs):
        self.mecab = MeCab(options=None, kwargs=kwargs)

    def __convert(self, mecab_token):
        surface = mecab_token.surface
        fs = mecab_token.feature.split(',')

        (pos1, pos2, pos3, pos4, conjugation_form, conjugation_type, base_form, reading, pronunciation) = \
            list(map(lambda f: None if f == '*' else f, fs)) + [None,] * max(0, 9 - len(fs))

        if surface == '' and pos1 == 'BOS/EOS':
            return PyMecab.EOS

        return Token(surface, pos1, pos2, pos3, pos4, conjugation_form, conjugation_type, base_form, reading,
                            pronunciation)

    def tokenize(self, text):
        return [self.__convert(t) for t in self.mecab.parse(text, as_nodes=True)]


def main():
    import sys

    mecab = PyMecab()

    for line in sys.stdin:
        for token in mecab.tokenize(line):
            print(token.surface, token.pos1)

        print('')

if __name__ == "__main__":
    main()